package com.hyperling.apps.example_sqlite_addressbook;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.DialogFragment;
import android.app.Fragment;
import android.content.Context;
import android.content.DialogInterface;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.EditText;

/**
 * Created by ling on 12/13/15.
 */
public class AddEditFragment extends Fragment {
    public interface AddEditFragmentListener {
        public void onAddEditCompleted(long rowID);
    }

    private AddEditFragmentListener listener;

    private long rowID;

    private Bundle contactInfoBundle;

    private EditText etName;
    private EditText etPhone;
    private EditText etEmail;
    private EditText etStreet;
    private EditText etCity;
    private EditText etState;
    private EditText etZip;

    @Override
    public void onAttach(Activity activity){
        super.onAttach(activity);
        listener = (AddEditFragmentListener) activity;
    }

    @Override
    public void onDetach(){
        super.onDetach();
        listener = null;
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
        super.onCreateView(inflater, container, savedInstanceState);
        setRetainInstance(true);
        setHasOptionsMenu(true);

        View view = inflater.inflate(R.layout.fragment_add_edit, container, false);
        etName = (EditText) view.findViewById(R.id.et_name);
        etPhone = (EditText) view.findViewById(R.id.et_phone);
        etEmail = (EditText) view.findViewById(R.id.et_email);
        etStreet = (EditText) view.findViewById(R.id.et_street);
        etCity = (EditText) view.findViewById(R.id.et_city);
        etState = (EditText) view.findViewById(R.id.et_state);
        etZip = (EditText) view.findViewById(R.id.et_zip);

        contactInfoBundle = getArguments();

        if (contactInfoBundle != null){
            rowID = contactInfoBundle.getLong(MainActivity.ROW_ID);
            etName.setText(contactInfoBundle.getString("name"));
            etPhone.setText(contactInfoBundle.getString("phone"));
            etEmail.setText(contactInfoBundle.getString("email"));
            etStreet.setText(contactInfoBundle.getString("street"));
            etCity.setText(contactInfoBundle.getString("city"));
            etState.setText(contactInfoBundle.getString("state"));
            etZip.setText(contactInfoBundle.getString("zip"));
        }

        Button btnSave = (Button) view.findViewById(R.id.btn_save);
        btnSave.setOnClickListener(saveButtonClicked);

        return view;
    }

    View.OnClickListener saveButtonClicked = new View.OnClickListener() {
        @Override
        public void onClick(View v) {
            if (etName.getText().toString().trim().length() > 0){
                AsyncTask<Object, Object, Object> saveContactTask = new AsyncTask<Object, Object, Object>() {
                    @Override
                    protected Object doInBackground(Object... params) {
                        saveContact();
                        return null;
                    }

                    @Override
                    protected void onPostExecute(Object results){
                        InputMethodManager imm = (InputMethodManager) getActivity().getSystemService(Context.INPUT_METHOD_SERVICE);
                        imm.hideSoftInputFromWindow(getView().getWindowToken(), 0);

                        listener.onAddEditCompleted(rowID);
                    }
                };

                saveContactTask.execute((Object[]) null);
            }
            else{
                DialogFragment errorSaving = new DialogFragment(){
                    @Override
                    public Dialog onCreateDialog(Bundle savedInstanceState){
                        AlertDialog.Builder builder = new AlertDialog.Builder(getActivity());

                        builder.setMessage(R.string.error_create_contact);
                        builder.setPositiveButton(R.string.msg_confirm_ok_button, null);

                        return builder.create();
                    }
                };

                errorSaving.show(getFragmentManager(), "Error saving contact");
            }
        }
    };

    private void saveContact(){
        DatabaseConnector databaseConnector = new DatabaseConnector(getActivity());

        if (contactInfoBundle == null) {
            rowID = databaseConnector.insertContact(
                    etName.getText().toString(),
                    etPhone.getText().toString(),
                    etEmail.getText().toString(),
                    etStreet.getText().toString(),
                    etCity.getText().toString(),
                    etState.getText().toString(),
                    etZip.getText().toString()
            );
        }
        else{
            databaseConnector.updateContact(
                    rowID,
                    etName.getText().toString(),
                    etPhone.getText().toString(),
                    etEmail.getText().toString(),
                    etStreet.getText().toString(),
                    etCity.getText().toString(),
                    etState.getText().toString(),
                    etZip.getText().toString()
            );
        }
    }
}
