package com.hyperling.apps.example_sqlite_addressbook;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.DialogFragment;
import android.app.Fragment;
import android.content.DialogInterface;
import android.database.Cursor;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

/**
 * Created by ling on 12/13/15.
 */
public class DetailsFragment extends Fragment {

    public interface DetailsFragmentListener{
        public void onContactDeleted();
        public void onEditContact(Bundle arguments);
    }

    private DetailsFragmentListener listener;

    private long rowID = -1;

    private TextView tvName;
    private TextView tvPhone;
    private TextView tvEmail;
    private TextView tvStreet;
    private TextView tvCity;
    private TextView tvState;
    private TextView tvZip;

    @Override
    public void onAttach(Activity activity){
        super.onAttach(activity);
        listener = (DetailsFragmentListener) activity;
    }

    @Override
    public void onDetach(){
        super.onDetach();
        listener = null;
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
        super.onCreateView(inflater, container, savedInstanceState);
        setRetainInstance(true);

        if (savedInstanceState != null){
            rowID = savedInstanceState.getLong(MainActivity.ROW_ID);
        }
        else{
            Bundle arguments = getArguments();

            if (arguments != null){
                rowID = arguments.getLong(MainActivity.ROW_ID);
            }
        }

        View view = inflater.inflate(R.layout.fragment_details, container, false);
        setHasOptionsMenu(true);

        tvName = (TextView) view.findViewById(R.id.tv_name);
        tvPhone = (TextView) view.findViewById(R.id.tv_phone);
        tvEmail = (TextView) view.findViewById(R.id.tv_email);
        tvStreet = (TextView) view.findViewById(R.id.tv_street);
        tvCity = (TextView) view.findViewById(R.id.tv_city);
        tvState = (TextView) view.findViewById(R.id.tv_state);
        tvZip = (TextView) view.findViewById(R.id.tv_zip);

        return view;
    }

    @Override
    public void onResume(){
        super.onResume();
        new LoadContactTask().execute(rowID);
    }

    @Override
    public void onSaveInstanceState(Bundle outState){
        super.onSaveInstanceState(outState);
        outState.putLong(MainActivity.ROW_ID, rowID);
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater){
        super.onCreateOptionsMenu(menu, inflater);
        inflater.inflate(R.menu.fragment_details_menu, menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item){
        switch(item.getItemId()){
            case R.id.action_edit:
                Bundle arguments = new Bundle();

                arguments.putLong(MainActivity.ROW_ID, rowID);
                arguments.putCharSequence("name", tvName.getText());
                arguments.putCharSequence("phone", tvPhone.getText());
                arguments.putCharSequence("email", tvEmail.getText());
                arguments.putCharSequence("street", tvStreet.getText());
                arguments.putCharSequence("city", tvCity.getText());
                arguments.putCharSequence("state", tvState.getText());
                arguments.putCharSequence("zip", tvZip.getText());
                return true;
            case R.id.action_delete:
                deleteContact();
                return true;
        }

        return super.onOptionsItemSelected(item);
    }

    private class LoadContactTask extends AsyncTask<Long, Object, Cursor>{
        DatabaseConnector databaseConnector = new DatabaseConnector(getActivity());

        @Override
        protected Cursor doInBackground(Long... params){
            databaseConnector.open();
            return databaseConnector.getOneContact(params[0]);
        }

        @Override
        protected void onPostExecute(Cursor result){
            super.onPostExecute(result);

            result.moveToFirst();

            int iName = result.getColumnIndex("name");
            int iPhone = result.getColumnIndex("phone");
            int iEmail = result.getColumnIndex("email");
            int iStreet = result.getColumnIndex("street");
            int iCity = result.getColumnIndex("city");
            int iState = result.getColumnIndex("state");
            int iZip = result.getColumnIndex("zip");

            tvName.setText(result.getString(iName));
            tvPhone.setText(result.getString(iPhone));
            tvEmail.setText(result.getString(iEmail));
            tvStreet.setText(result.getString(iStreet));
            tvCity.setText(result.getString(iCity));
            tvState.setText(result.getString(iState));
            tvZip.setText(result.getString(iZip));

            result.close();
            databaseConnector.close();
        }

        private void deleteContact(){
            confirmDelete.show(getFragmentManager(), "confirm delete");
        }

        private DialogFragment confirmDelete = new DialogFragment(){
            @Override
            public Dialog onCreateDialog(Bundle bundle){
                AlertDialog.Builder builder = new AlertDialog.Builder(getActivity());

                builder.setTitle(R.string.msg_confirm_title);
                builder.setMessage(R.string.msg_confirm_text);

                builder.setPositiveButton(R.string.msg_confirm_ok_button, new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        final DatabaseConnector databaseConnector = new DatabaseConnector(getActivity());

                        AsyncTask<Long, Object, Cursor> deleteTask = new AsyncTask<Long, Object, Cursor>() {
                            @Override
                            protected Cursor doInBackground(Long... params) {
                                databaseConnector.deleteContact(params[0]);
                                return null;
                            }

                            @Override
                            protected void onPostExecute(Object result) {
                                listener.onContactDeleted();
                            }

                        };

                        deleteTask.execute(new Long[]{rowID});
                    }
                });

                builder.setNegativeButton(R.string.msg_confirm_cancel_button, null);
                return builder.create();
            }
        };
    }
}
